==> openj9-18_0.33.1.orig.tar.xz: src-openj9-18-0.33.1/omr/compiler/arm/env/OMRCompilerEnv.hpp <==
/*******************************************************************************
 * Copyright (c) 2000, 2020 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at http://eclipse.org/legal/epl-2.0
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License, v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception [1] and GNU General Public
 * License, version 2 with the OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/

#ifndef OMR_ARM_COMPILER_ENV_INCL
#define OMR_ARM_COMPILER_ENV_INCL

/*
 * The following #define and typedef must appear before any #includes in this file
 */
#ifndef OMR_COMPILER_ENV_CONNECTOR
#define OMR_COMPILER_ENV_CONNECTOR
namespace OMR { namespace ARM { class CompilerEnv; } }
namespace OMR { typedef OMR::ARM::CompilerEnv CompilerEnvConnector; }
#else
#error OMR::ARM::CompilerEnv expected to be a primary connector, but an OMR connector is already defined
#endif

#include "compiler/env/OMRCompilerEnv.hpp"
#include "infra/Annotations.hpp"
#include "env/RawAllocator.hpp"


namespace OMR
{

namespace ARM
{

class OMR_EXTENSIBLE CompilerEnv : public OMR::CompilerEnv
   {
public:

   CompilerEnv(TR::RawAllocator raw, const TR::PersistentAllocatorKit &persistentAllocatorKit, OMRPortLibrary * const portLib=NULL) :
         OMR::CompilerEnv(raw, persistentAllocatorKit, portLib)
      {}

   // Initialize 'target' environment for this compilation
   //
   void initializeTargetEnvironment();

   };

}

}

#endif

==> openj9-21_0.56.0.orig.tar.xz: src-openj9-21-0.56.0/omr/compiler/arm/env/OMRCompilerEnv.hpp <==
/*******************************************************************************
 * Copyright IBM Corp. and others 2000
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License, v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception [1] and GNU General Public
 * License, version 2 with the OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 *******************************************************************************/

#ifndef OMR_ARM_COMPILER_ENV_INCL
#define OMR_ARM_COMPILER_ENV_INCL

/*
 * The following #define and typedef must appear before any #includes in this file
 */
#ifndef OMR_COMPILER_ENV_CONNECTOR
#define OMR_COMPILER_ENV_CONNECTOR

namespace OMR {
namespace ARM {
class CompilerEnv;
}

typedef OMR::ARM::CompilerEnv CompilerEnvConnector;
} // namespace OMR
#else
#error OMR::ARM::CompilerEnv expected to be a primary connector, but an OMR connector is already defined
#endif

#include "compiler/env/OMRCompilerEnv.hpp"
#include "infra/Annotations.hpp"
#include "env/RawAllocator.hpp"

namespace OMR { namespace ARM {

class OMR_EXTENSIBLE CompilerEnv : public OMR::CompilerEnv {
public:
    CompilerEnv(TR::RawAllocator raw, const TR::PersistentAllocatorKit &persistentAllocatorKit,
        OMRPortLibrary * const portLib = NULL)
        : OMR::CompilerEnv(raw, persistentAllocatorKit, portLib)
    {}

    // Initialize 'target' environment for this compilation
    //
    void initializeTargetEnvironment();
};

}} // namespace OMR::ARM

#endif
